DppError

Enum DppError 

#[non_exhaustive]
pub enum DppError { NotFound(String), InvalidTransition { current: String, required: String, }, Validation(ValidationErrors), Signing(String), Serialisation(String), RetentionLocked, Internal(String), }
Top-level error type for the DPP domain.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotFound(String)



InvalidTransition

Fields

current: String
required: String


Validation(ValidationErrors)



Signing(String)



Serialisation(String)



RetentionLocked

Returned when an attempt is made to delete or overwrite a passport that has been published and is therefore subject to EU ESPR retention obligations. Published passports must remain accessible for the legally defined period under the applicable delegated act (typically 10–15 years).



Internal(String)